summaryrefslogtreecommitdiff
path: root/src/mesa/main/texformat.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/main/texformat.c')
-rw-r--r--src/mesa/main/texformat.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/mesa/main/texformat.c b/src/mesa/main/texformat.c
index dae98bcc6f..60b2065a6c 100644
--- a/src/mesa/main/texformat.c
+++ b/src/mesa/main/texformat.c
@@ -1351,14 +1351,13 @@ _mesa_choose_tex_format( GLcontext *ctx, GLint internalFormat,
/**
* Return datatype and number of components per texel for the
* given gl_texture_format.
*/
void
-_mesa_format_to_type_and_comps(const struct gl_texture_format *format,
+_mesa_format_to_type_and_comps(gl_format format,
GLenum *datatype, GLuint *comps)
{
- switch (format->MesaFormat) {
+ switch (format) {
case MESA_FORMAT_RGBA8888:
case MESA_FORMAT_RGBA8888_REV:
case MESA_FORMAT_ARGB8888:
@@ -1351,14 +1351,13 @@ _mesa_choose_tex_format( GLcontext *ctx, GLint internalFormat,
/**
- * Return datatype and number of components per texel for the
- * given gl_texture_format.
+ * Return datatype and number of components per texel for the given gl_format.
*/
void